@@ -1,6 +1,6 @@
 from typing import Optional
 from math import pi
-from pyssage.classes import Number
+from pyssage.classes import Number, VoronoiTessellation
 import pyssage.connections
 import pyssage.distances
 import pyssage.utils
@@ -10,9 +10,13 @@ from matplotlib import collections, colors
 # import matplotlib.patches as mpatches
 import numpy
 
+__all__ = ["FigOutput", "draw_angular_correlation", "draw_bearing", "draw_bearing_correlogram", "draw_connections",
+           "draw_correlogram", "draw_distance_class_distribution", "draw_quadvar_result", "draw_shortest_path",
+           "draw_tessellation", "draw_transect", "draw_windrose_correlogram"]
+
 
 class FigOutput:
-    def __init__(self, figsize: tuple = (8, 6), dpi: int = 100, figshow: bool = False, figname: str = "",
+    def __init__(self, figsize: tuple = (8, 6), dpi: int = 100, figshow: bool = True, figname: str = "",
                  figformat: str = "png"):
         self.figsize = figsize
         self.dpi = dpi
@@ -79,12 +83,12 @@ def draw_transect(transect: numpy.array, unit_scale: Number = 1, title: str = ""
     finalize_figure(fig, axs, figoutput, title)
 
 
-def draw_quadvar_result(quadvar: numpy.ndarray, rand_ci: Optional[numpy.ndarray] = None, title: str = "",
+def draw_quadvar_result(quadvar: numpy.ndarray, inc_random: bool = False, title: str = "",
                         varlabel: str = "", randlabel: str = "", figoutput: Optional[FigOutput] = None) -> None:
     fig, axs = start_figure(figoutput)
     axs.plot(quadvar[:, 0], quadvar[:, 1], label=varlabel)
-    if rand_ci is not None:
-        axs.plot(quadvar[:, 0], rand_ci, label=randlabel)
+    if inc_random:
+        axs.plot(quadvar[:, 0], quadvar[:, 2], label=randlabel)
         pyplot.legend(loc="upper right")
     axs.set_xlabel("Scale")
     axs.set_ylabel("Variance")
@@ -115,8 +119,8 @@ def draw_quadvar_result(quadvar: numpy.ndarray, rand_ci: Optional[numpy.ndarray]
 #     pyplot.show()
 
 
-def draw_tessellation(tessellation, xcoords: numpy.ndarray, ycoords: numpy.ndarray, title: str = "",
-                      figoutput: Optional[FigOutput] = None) -> None:
+def draw_tessellation(tessellation: VoronoiTessellation, xcoords: numpy.ndarray, ycoords: numpy.ndarray,
+                      title: str = "", figoutput: Optional[FigOutput] = None) -> None:
     fig, axs = start_figure(figoutput)
     minx = min(xcoords)
     maxx = max(xcoords)
@@ -235,19 +239,21 @@ def draw_distance_class_distribution(dist_matrix: numpy.ndarray, dist_class: num
 
 
 def draw_correlogram(data: numpy.ndarray, metric_title: str = "", title: str = "", alpha: float = 0.05,
-                     is_mantel: bool = False, figoutput: Optional[FigOutput] = None):
+                     figoutput: Optional[FigOutput] = None):
     fig, axs = start_figure(figoutput)
 
     # column order is: min_scale, max_scale, # pairs, expected, observed, sd, z, prob
     # sd is absent from Mantel correlograms
+    _, ncols = data.shape
     min_col = 0
     max_col = 1
     exp_col = 3
     obs_col = 4
-    if is_mantel:
-        p_col = 6
-    else:
-        p_col = 7
+    p_col = ncols - 1
+    # if is_mantel:
+    #     p_col = 6
+    # else:
+    #     p_col = 7
 
     # plot at midpoint of distance range
     scale = numpy.array([x[min_col] + (x[max_col] - x[min_col])/2 for x in data])
@@ -351,11 +357,13 @@ def draw_bearing_correlogram(data: numpy.ndarray, title: str = "", symmetric: bo
     fig, axs = start_figure(figoutput, polar=True)
 
     # column order is: min_scale, max_scale, bearing, # pairs, expected, observed, sd, z, prob
+    _, ncols = data.shape
     mindist_col = 0
     b_col = 2
     exp_col = 4
     obs_col = 5
-    p_col = 8
+    # p_col = 8
+    p_col = ncols - 1
     dist_classes = sorted(set(data[:, mindist_col]))
     n_dists = len(dist_classes)
     deviation = data[:, obs_col] - data[:, exp_col]
@@ -380,7 +388,7 @@ def draw_bearing_correlogram(data: numpy.ndarray, title: str = "", symmetric: bo
     else:  # Moran's I
         normalize = colors.Normalize(vmin=-1, vmax=1)
     p_colors = pyplot.cm.bwr_r(normalize(data[:, obs_col]))
-    print(p_colors)
+    # print(p_colors)
     if symmetric:
         r = numpy.append(r, r)
         theta = numpy.append(theta, theta + pi)
@@ -389,7 +397,7 @@ def draw_bearing_correlogram(data: numpy.ndarray, title: str = "", symmetric: bo
         base_circle = numpy.append(base_circle, base_circle)
         edges = edges + edges
     drop_lines = [[(theta[i], base_circle[i]), (theta[i], r[i])] for i in range(len(r))]
-    print(p_colors)
+    # print(p_colors)
 
     drop_collection = collections.LineCollection(drop_lines, colors="silver", zorder=1)
     axs.add_collection(drop_collection)
@@ -406,8 +414,7 @@ def draw_bearing_correlogram(data: numpy.ndarray, title: str = "", symmetric: bo
 
 
 def draw_windrose_correlogram(data: numpy.ndarray, title: str = "", symmetric: bool = True, alpha: float = 0.05,
-                              show_counts: bool = False, is_mantel: bool = False,
-                              figoutput: Optional[FigOutput] = None):
+                              show_counts: bool = False, figoutput: Optional[FigOutput] = None):
     fig, axs = start_figure(figoutput, polar=True)
 
     # pre-determined spacing between sectors in each annulus
@@ -416,16 +423,18 @@ def draw_windrose_correlogram(data: numpy.ndarray, title: str = "", symmetric: b
 
     # column order is: min_scale, max_scale, min_angle, max_angle, # pairs, expected, observed, sd, z, prob
     # sd is absent from Mantel correlograms
+    _, ncols = data.shape
     mindist_col = 0
     sang_col = 2
     eang_col = 3
     np_col = 4
     exp_col = 5
     obs_col = 6
-    if is_mantel:
-        p_col = 8
-    else:
-        p_col = 9
+    p_col = ncols - 1
+    # if is_mantel:
+    #     p_col = 8
+    # else:
+    #     p_col = 9
     annuli = set(data[:, mindist_col])
     annuli = sorted(annuli)
     n_annuli = len(annuli)
@@ -548,42 +557,68 @@ def draw_windrose_correlogram(data: numpy.ndarray, title: str = "", symmetric: b
     finalize_figure(fig, axs, figoutput, title)
 
 
-def draw_bearing(data: numpy.ndarray, alpha: float = 0.05, title: str = "", figoutput: Optional[FigOutput] = None):
-    fig, axs = start_figure(figoutput)
-
-    # # column order is: min_scale, max_scale, # pairs, expected, observed, sd, z, prob
-    # min_col = 0
-    # max_col = 1
-    # exp_col = 3
-    # obs_col = 4
-    # p_col = 7
-    #
-    # # plot at midpoint of distance range
-    # scale = numpy.array([x[min_col] + (x[max_col] - x[min_col])/2 for x in data])
-    #
+def draw_bearing(data: numpy.ndarray, alpha: float = 0.05, title: str = "", draw_polar: bool = False,
+                 figoutput: Optional[FigOutput] = None):
+    fig, axs = start_figure(figoutput, draw_polar)
     n = len(data)
+    _, ncols = data.shape
+    p_col = ncols - 1
 
-    # draw expected value
-    y = [0, 0]
-    x = [data[0, 0], data[n-1, 0]]
-    line = Line2D(x, y, color="silver", zorder=1)
-    axs.add_line(line)
+    if not draw_polar:
+        # draw expected value
+        y = [0, 0]
+        x = [data[0, 0], data[n-1, 0]]
+        line = Line2D(x, y, color="silver", zorder=1)
+        axs.add_line(line)
 
-    # draw base line
-    axs.plot(data[:, 0], data[:, 1], zorder=2)
+        # draw base line
+        axs.plot(data[:, 0], data[:, 1], zorder=2)
+        axs.set_xlabel("Bearing")
+        axs.set_ylabel("Mantel Correlation")
 
     # mark significant bearings
-    sig_mask = [p <= alpha for p in data[:, 2]]
-    x = data[sig_mask, 0]
-    y = data[sig_mask, 1]
+    sig_mask = [p <= alpha for p in data[:, p_col]]
+
+    if draw_polar:
+        x = numpy.radians(numpy.append(data[sig_mask, 0], data[sig_mask, 0]+180))
+        y = numpy.abs(numpy.append(data[sig_mask, 1], data[sig_mask, 1]))
+    else:
+        x = data[sig_mask, 0]
+        y = data[sig_mask, 1]
     pyplot.scatter(x, y, color="black", edgecolors="black", zorder=3, s=25)
 
     # mark non-significant scales
     ns_mask = numpy.invert(sig_mask)
-    x = data[ns_mask, 0]
-    y = data[ns_mask, 1]
+    if draw_polar:
+        x = numpy.radians(numpy.append(data[ns_mask, 0], data[ns_mask, 0]+180))
+        y = numpy.abs(numpy.append(data[ns_mask, 1], data[ns_mask, 1]))
+    else:
+        x = data[ns_mask, 0]
+        y = data[ns_mask, 1]
     pyplot.scatter(x, y, color="white", edgecolors="black", zorder=3, s=15)
 
-    axs.set_xlabel("Bearing")
-    axs.set_ylabel("Mantel Correlation")
+    finalize_figure(fig, axs, figoutput, title)
+
+
+def draw_angular_correlation(data: numpy.ndarray, title: str = "", draw_polar: bool = True,
+                             figoutput: Optional[FigOutput] = None):
+    fig, axs = start_figure(figoutput, polar=draw_polar)
+    if draw_polar:
+        pos_mask = [r >= 0 for r in data[:, 1]]
+        pyplot.scatter(numpy.radians(data[pos_mask, 0]), numpy.abs(data[pos_mask, 1]), color="red", edgecolors="black",
+                       zorder=3)
+        neg_mask = numpy.invert(pos_mask)
+        pyplot.scatter(numpy.radians(data[neg_mask, 0]), numpy.abs(data[neg_mask, 1]), color="blue", edgecolors="black",
+                       zorder=3)
+        axs.set_ylim(0, 1)
+    else:
+        # draw expected value
+        y = [0, 0]
+        x = [data[0, 0], data[len(data) - 1, 0]]
+        line = Line2D(x, y, color="silver", zorder=1)
+        axs.add_line(line)
+        pyplot.scatter(data[:, 0],data[:, 1], zorder=2)
+        axs.set_xlabel("Bearing")
+        axs.set_ylabel("Correlation")
+        axs.set_ylim(-1, 1)
     finalize_figure(fig, axs, figoutput, title)
