@@ -3069,7 +3069,7 @@ def test_ttlqv_random():
     # produces a visual result for general insepction
     summary, _ = pyssage.quadvar.quadrat_variance_randomization(pyssage.quadvar.ttlqv, 100, create_test_transect(),
                                                                 max_block_size=100)
-    pyssage.graph.draw_quadvar_result(summary[:, 0:2], summary[:, 2], title="TTLQV Test with Randomization",
+    pyssage.graph.draw_quadvar_result(summary, inc_random=True, title="TTLQV Test with Randomization",
                                       varlabel="Observed", randlabel="{:0.2%} confidence limit".format(0.95),
                                       figoutput=pyssage.graph.FigOutput(figshow=True))
 
@@ -3079,7 +3079,7 @@ def test_threetlqv_random():
     # produces a visual result for general insepction
     summary, _ = pyssage.quadvar.quadrat_variance_randomization(pyssage.quadvar.three_tlqv, 100, create_test_transect(),
                                                                 max_block_size=100)
-    pyssage.graph.draw_quadvar_result(summary[:, 0:2], summary[:, 2], title="3TLQV Test with Randomization",
+    pyssage.graph.draw_quadvar_result(summary, inc_random=True, title="3TLQV Test with Randomization",
                                       varlabel="Observed", randlabel="{:0.2%} confidence limit".format(0.95),
                                       figoutput=pyssage.graph.FigOutput(figshow=True))
 
@@ -3089,7 +3089,7 @@ def test_pqv_random():
     # produces a visual result for general insepction
     summary, _ = pyssage.quadvar.quadrat_variance_randomization(pyssage.quadvar.pqv, 50, create_test_transect(),
                                                                 max_block_size=50)
-    pyssage.graph.draw_quadvar_result(summary[:, 0:2], summary[:, 2], title="PQV Test with Randomization",
+    pyssage.graph.draw_quadvar_result(summary, inc_random=True, title="PQV Test with Randomization",
                                       varlabel="Observed", randlabel="{:0.2%} confidence limit".format(0.95),
                                       figoutput=pyssage.graph.FigOutput(figshow=True))
 
@@ -3099,7 +3099,7 @@ def test_tqv_random():
     # produces a visual result for general insepction
     summary, _ = pyssage.quadvar.quadrat_variance_randomization(pyssage.quadvar.tqv, 50, create_test_transect(),
                                                                 max_block_size=50)
-    pyssage.graph.draw_quadvar_result(summary[:, 0:2], summary[:, 2], title="TQV Test with Randomization",
+    pyssage.graph.draw_quadvar_result(summary, inc_random=True, title="TQV Test with Randomization",
                                       varlabel="Observed", randlabel="{:0.2%} confidence limit".format(0.95),
                                       figoutput=pyssage.graph.FigOutput(figshow=True))
 
@@ -3109,7 +3109,7 @@ def test_2nlv_random():
     # produces a visual result for general insepction
     summary, _ = pyssage.quadvar.quadrat_variance_randomization(pyssage.quadvar.two_nlv, 100, create_test_transect(),
                                                                 max_block_size=100)
-    pyssage.graph.draw_quadvar_result(summary[:, 0:2], summary[:, 2], title="2NLV Test with Randomization",
+    pyssage.graph.draw_quadvar_result(summary, inc_random=True, title="2NLV Test with Randomization",
                                       varlabel="Observed", randlabel="{:0.2%} confidence limit".format(0.95),
                                       figoutput=pyssage.graph.FigOutput(figshow=True))
 
@@ -3119,7 +3119,7 @@ def test_threet_nlv_random():
     # produces a visual result for general insepction
     summary, _ = pyssage.quadvar.quadrat_variance_randomization(pyssage.quadvar.three_nlv, 100, create_test_transect(),
                                                                 max_block_size=100)
-    pyssage.graph.draw_quadvar_result(summary[:, 0:2], summary[:, 2], title="3NLV Test with Randomization",
+    pyssage.graph.draw_quadvar_result(summary, inc_random=True, title="3NLV Test with Randomization",
                                       varlabel="Observed", randlabel="{:0.2%} confidence limit".format(0.95),
                                       figoutput=pyssage.graph.FigOutput(figshow=True))
 
@@ -3222,3 +3222,33 @@ def test_5qv():
     pyssage.graph.draw_quadvar_result(result, title="5QV Test", figoutput=pyssage.graph.FigOutput(figshow=True))
     for i in range(33):
         assert round(result[i, 1], 5) == answer[i]
+
+
+def test_4tlqv_random():
+    # fixed answer not possible due to stochastic nature of test. instead tests algorithm does not crash and
+    # produces a visual result for general insepction
+    summary, _ = pyssage.quadvar.quadrat_variance_randomization(pyssage.quadvar.four_tlqv, 100, create_test_surface(),
+                                                                max_block_size=50)
+    pyssage.graph.draw_quadvar_result(summary[:, 0:2], summary[:, 2], title="4TLQV Test with Randomization",
+                                      varlabel="Observed", randlabel="{:0.2%} confidence limit".format(0.95),
+                                      figoutput=pyssage.graph.FigOutput(figshow=True))
+
+
+def test_9tlqv_random():
+    # fixed answer not possible due to stochastic nature of test. instead tests algorithm does not crash and
+    # produces a visual result for general insepction
+    summary, _ = pyssage.quadvar.quadrat_variance_randomization(pyssage.quadvar.nine_tlqv, 100, create_test_surface(),
+                                                                max_block_size=33)
+    pyssage.graph.draw_quadvar_result(summary[:, 0:2], summary[:, 2], title="9TLQV Test with Randomization",
+                                      varlabel="Observed", randlabel="{:0.2%} confidence limit".format(0.95),
+                                      figoutput=pyssage.graph.FigOutput(figshow=True))
+
+
+def test_5qv_random():
+    # fixed answer not possible due to stochastic nature of test. instead tests algorithm does not crash and
+    # produces a visual result for general insepction
+    summary, _ = pyssage.quadvar.quadrat_variance_randomization(pyssage.quadvar.five_qv, 100, create_test_surface(),
+                                                                max_block_size=50)
+    pyssage.graph.draw_quadvar_result(summary[:, 0:2], summary[:, 2], title="5QV Test with Randomization",
+                                      varlabel="Observed", randlabel="{:0.2%} confidence limit".format(0.95),
+                                      figoutput=pyssage.graph.FigOutput(figshow=True))
